@@ -57,7 +57,8 @@ def set_mlops_import(req_file):
 
 def to_folder(path, folder_path):
     """
-    Copy folders, files or package data to a given folder
+    Copy folders, files or package data to a given folder.
+    Note that if target exists it will be overwritten.
     Input:
       - path: supported formats
             - folder path (string): e,g, "my/folder" 
@@ -101,7 +102,8 @@ def run_tests(test_path, path_type='file'):
       - path_type: either 'file' (test_path refers then to files/folders) or
         'module' (test_path refers then to modules)
     """
-    command = [sys.executable, "-m", "pytest", "--quiet"]
+    command = [sys.executable, "-m", "pytest", 
+                "--quiet", "--color=no", "-W ignore:numpy.ufunc size changed"]
     if path_type == 'module':
         command.append("--pyargs")
     if isinstance(test_path, str):
@@ -127,8 +129,7 @@ def set_up_requirements(c):
     dev)
     """
     logging.info("Create requirement file")
-    if "akerbp/mlops" in get_repo_origin():
-        set_mlops_import(c.req_file)
+    set_mlops_import(c.req_file)
     shutil.move(c.req_file, 'requirements.txt')
     c.req_file = 'requirements.txt'
     if env != "dev":
